# -*- encoding:utf-8 -*-
import concurrent.futures

from flask_app.general.llm.doubao import doubao_model
from flask_app.general.llm.qianwen_plus import qianwen_plus


# 多线程压力测试
def multi_threaded_calls_doubao(user_query, num_threads=10):
    """
    使用多线程同时调用 doubao_model 函数。
    参数：
    - user_query: 用户查询
    - num_threads: 并发线程数量（默认 10）
    """
    results = []

    # 定义一个辅助函数来调用 doubao_model 并返回结果
    def call_function(thread_id):
        print(f"线程 {thread_id} 开始调用 doubao_model")
        result = qianwen_plus(user_query)
        return result

    # 使用 ThreadPoolExecutor 来管理线程池
    with concurrent.futures.ThreadPoolExecutor(max_workers=num_threads) as executor:
        # 提交所有任务
        futures = {executor.submit(call_function, i + 1): i + 1 for i in range(num_threads)}

        # 处理完成的任务
        for future in concurrent.futures.as_completed(futures):
            thread_id = futures[future]
            try:
                data = future.result()
                results.append(data)
                if data:  # 打印返回的部分结果
                    print(f"线程 {thread_id} 完成，返回数据：{data[:50]}...")  # 只打印前50个字符
                else:
                    print(f"线程 {thread_id} 完成，但返回结果为空。")
            except Exception as exc:
                print(f"线程 {thread_id} 生成异常：{exc}")

    return results


if __name__ == "__main__":
    # 定义参数
    # user_query = "请简要介绍豆包Pro模型的功能"
    user_query="""
    请根据货物标中采购要求部分的内容，告诉我交通信号灯技术要求下的信号灯灯杆的技术参数或采购要求是什么。请以 JSON 格式返回结果，键名为"交通信号灯技术要求.信号灯灯杆"，键值为一个列表，列表中包含若干描述"交通信号灯技术要求下的信号灯灯杆"的技术参数或采购要求或功能说明的字符串，请按原文内容回答，保留三角▲、五角★和序号，不可擅自增删内容，尤其是不可擅自添加序号。

要求与指南：
1. 你的键值应该全面，不要遗漏。
    -a.若技术参数或采购要求在表格中，那么单元格内的内容基本都要涵盖
        -对于单元格内以序号分隔的各条参数要求，应逐条提取，并分别作为键值中的字符串列表项。
        -对于无序号标明且在同一单元格内的参数要求或功能说明，也要根据语义分别添加进键值中。
    -b.若技术参数或采购要求在正文部分，应准确定位到与目标货物（设备、系统、功能模块）相关的内容，将其后的技术参数或采购要求或功能说明完整提取，逐一添加到键值的字符串列表中，不得擅自添加或修改序号。
2. 如果存在嵌套结构，且原文为Markdown 的表格语法，如'摄像机|有效像素|≥900W像素'， 请不要返回该Markdown语法，而是使用冒号':'将相关信息拼接在一起，生成一条完整且清晰的技术参数（或采购要求）描述，作为列表中的一个字符串。如"摄像机：有效像素：≥900W像素"。
3. 字符串中的内容为具体的技术参数要求或采购要求，请不要返回诸如'（1）高清录像功能'这种标题性质且不能体现要求的内容。
4. 如果该货物没有相关采购要求或技术参数要求，键值应为空列表[]。

### 示例输出1如下：
{{
    "摄像机控制键盘": [
        "1、▲支持串行 RS232/RS422 和 IP 混合控制，允许在一个控制器上使用 RS232/RS422/IP 控制单个系统中的摄像机；",
        "2、支持 2 组 RS422 串口 VISCA 协议菊花链控制 2x7 台摄像机。",
        "★能够自动对焦，提供检测报告"
    ]
}}

### 示例输出2如下（包含嵌套结构）：
{{
    "摄像机": [
        "摄像机：有效像素：≥900W像素",
        "摄像机：最低照度：彩色≤0.001lx",
        "协议：routes 接口开放：具备；▲支持标准 ONVIF 协议与第三方厂家设备进行互联；支持 GB/T28181；应提供 SDK"
    ]
}}

文件内容：
购法实施条例》、《政府采购货物和服务招标投标管理办法》及相关法律法规

43. 政府采购合同的履行、违约责任和解决争议的方法等适用《合同法》

## 十二、招标文件的解释权

44. 招标文件的最终解释权为采购人、分散采购机构所有。

## 第三章项目技术、服务及商务要求

### 相关技术标准

本技术规格依据以下技术标准编制,技术规格中仅列举了主要的技术指标及项目,其它指标及项目要求详见相应技术标准。

1)《中华人民共和国道路交通安全法实施条例》

2)《城市道路交通设施设计规范》(GB 50688-2011,2019 年修订版

3)《道路交通标志和标线》(GB 5768.2-2009

4)《道路交通标志反光膜》(GB/T18833-2012

5)《路面标线涂料》(JT/T280-2004

6)《道路交通标线质量要求和检测方法》(GB/T 16311-2009

7)《道路交通信号灯设置与安装规范》(GB 14886-2016

8)《道路交通信号控制机》(GB 25280-2010

9)《公路交通安全设施设计技术规范》(JTG D81-2017

10)《闯红灯自动记录系统通用技术条件》(GA/T496-2014

11)《视频安防监控系统工程设计规范》(GB50395-2007

12)《视频安防监控系统技术要求》(GA/T367-2001)

13)《道路交通安全违法行为图像取证技术规范》(GA/T832-2014)

14)《机动车号牌图像自动识别技术规范》(GA/T833-2016)

15)《道路车辆智能监测记录系统通用技术条件》(GA/T497-2016

16)《公安交通指挥系统工程建设通用程序和要求》(GA/T651-2014

17)《公安交通管理外场设备基础设施施工通用要求》(GA/T652-2017

18)《安全防范工程技术标准》(GB50348-2018

19)《建筑物防雷设计规范》(GB50057-2010

20)《光纤通信系统通用规范》(SJ 20552-1995

21)《安全防范工程程序与要求》(GA/T75-1994

22)《安全防范系统验收规则》(GA308-2001

23)《安全防范系统通用图形符号》(GA/T74-2017

24)其它相关技术规范与标准

### 交通标线技术要求

#### 技术要求

1)热熔标线技术规范及要求。参考标准

1.投标货物必须符合中华人民共和国公共安全行业标准“GA/T298—2001《道路标线涂料》”、交通行业标准“JT/T280—2004《路面标线涂料》”及“GB/T24722《路而标线用玻璃珠》”的规范要求,重点指标要求如下

<table border="1" ><tr>
<td colspan="1" rowspan="2">检测项目</td>
<td colspan="2" rowspan="1">技术指标</td>
</tr><tr>
<td colspan="1" rowspan="1">反光型</td>
<td colspan="1" rowspan="1">凸起型</td>
</tr><tr>
<td colspan="1" rowspan="1">密度(g/cm3)</td>
<td colspan="2" rowspan="1">1.8-2.3 </td>
</tr><tr>
<td colspan="1" rowspan="1">软化点(℃)</td>
<td colspan="1" rowspan="1">90-125 </td>
<td colspan="1" rowspan="1">≥100</td>
</tr></table>

<table border="1" ><tr>
<td colspan="3" rowspan="1">不粘胎干燥时间</td>
<td colspan="2" rowspan="1"></td>
</tr><tr>
<td colspan="3" rowspan="1">涂抹外观</td>
<td colspan="2" rowspan="1">涂膜冷凝后应无皱纹、斑点、起泡、裂纹、脱落及表面发粘等现象,涂膜颜色和外观应与标准板差异不大。</td>
</tr><tr>
<td colspan="3" rowspan="1">抗压轻度</td>
<td colspan="1" rowspan="1"></td>
<td colspan="1" rowspan="1"></td>
</tr><tr>
<td colspan="3" rowspan="1">耐磨性(mg)负载1kg200 转后减重</td>
<td colspan="1" rowspan="1"></td>
<td colspan="1" rowspan="1">——</td>
</tr><tr>
<td colspan="3" rowspan="1">耐水性</td>
<td colspan="2" rowspan="1">经水浸泡24 小时后无异常</td>
</tr><tr>
<td colspan="3" rowspan="1">耐碱性</td>
<td colspan="2" rowspan="1">在氢氧化钙饱和溶液中浸24h 无异常现象</td>
</tr><tr>
<td colspan="3" rowspan="1">流动度(S) </td>
<td colspan="1" rowspan="1"></td>
<td colspan="1" rowspan="1">——</td>
</tr><tr>
<td colspan="3" rowspan="1">玻璃珠含量(%)</td>
<td colspan="2" rowspan="1">▲≥20</td>
</tr><tr>
<td colspan="1" rowspan="2">色度性能</td>
<td colspan="1" rowspan="2">白色</td>
<td colspan="1" rowspan="1">色品坐标(x, y) </td>
<td colspan="2" rowspan="1">在以下四角点色品坐标组成的四边形内(0.350,0.300);(0.290,0.340)(0.360,0.310);(0.320,0.370)</td>
</tr><tr>
<td colspan="1" rowspan="1">亮度因素</td>
<td colspan="2" rowspan="1">▲≥0.35</td>
</tr></table>

2.道路标线施划施工内容必须符合“GB5768—2009 中《道路标线》”的规范要求

3.标线质量要求

①投标人必须提供施工使用的热熔涂料及玻璃珠的相关质量证明文件(检测报告等)

▲②热熔标线旧标线的清除、采用高压水除线

★③热熔标线施划,标线表面加铺玻璃微珠,标线涂层厚度1.8mm±0.2mm

4.标线相关计量说明

4.1.本项目价格形式为固定单价,最终计量结算,按照工程量清单单价据实结算

5.道路热熔标线质保期12 个月

### 交通标志技术要求

#### 技术要求

##### 1.标志牌铝板技术标准:

①标志牌所采用铝板技术标准执行GB/T38/80—06

★②标志牌版面采用3mm 厚的铝板

##### 2.标志牌版面反光膜技术标准

①标志牌版面反光膜技术标准GB/T18833)—2012《道路交通反光膜》

★②标志牌反光膜采用Ⅳ类反光膜

③版面字体采用电脑刻字技术,标志版面颜色应符合GB5768—2017 规定

湖北众恒永业工程项目管理有限公司广水分公司编制

## 注:指路标志板面内容由采购方确认后制作

④标志牌版面反光膜质保期应不少于10 年。(投标人需在投标文件中作出承诺

## 3.标志牌杆件材料技术标准

★①标志标牌杆件立柱采用热浸镀锌内外表面防腐镀锌处理,热镀锌后再进行喷塑处理,应符合国家标准要求。

★②标志标牌杆件F 悬臂横梁采用热浸镀锌内外表面防腐镀锌处理,热镀锌后再进行喷塑处理,应符合国家标准要求。

★③标志标牌立柱和横梁采用无缝钢管。交通标志的连接件包括连接标志板滑槽与横梁和抱箍和螺栓、螺母,以及连接标志法兰盘与基础的地脚螺栓和螺母、专用不锈钢钢带等件,其材料的外形尺寸和机械性能应符合《道路交通标志板及支撑件》(GB/T23827-2009)相应标准要求。

## 4.标志标牌安装施工工艺技术标准

①标志标牌安装施工工艺必须符合“GB5768—2017 中《道路标志标线安装施工》”及《城市道路交通报纸和标线设置》(GB51038)的规范要求。

★②标志板与标志杆采用抱箍连接,抱箍必须经过热镀锌处理

## 5.标志标牌安装施工安全技术标准

①交通标志标牌安装位置准确,角度符合要求,且安装牢固

②严格执行交通安全维护与施工安全防护。标志基础应提前完成好养护,大型标志杆安装、大型标识标牌安装均应采用吊车、升降车配合人工完成,其他采用人工辅以小型机械施工作业。

③施工、保修符合现行有效的国家有关质量标准及实施规范

6.道路标志标牌质保期12 个月

## 交通信号灯技术要求

## 交通信号灯具

1、道路交通信号灯单灯必须符合国家标准GB14887-2011《道路交通信号灯》全部技术规定,并通过公安部交通安全产品质量监督检测中心的检测。

2、道路交通信号灯光源必须采用户外型超亮度发光二极管(LED),使用寿命不少于

50000 小时

3、信号灯灯具材质为铝质金属材料。机动车信号灯灯芯透镜尺寸采用￠400mm 规格,人行信号灯灯芯透镜尺寸采用￠300mm,相同规格的灯芯可以互换。信号灯外观应与目前广水市使用的信号灯外观相一致。

4、信号灯需采用恒流供电电路,单体信号灯功率￠400mm 规格不超过20VA;￠300mm 规格不超过15VA。

## 倒计时器

1、道路交通信号倒计时器安装在信号灯的上方或右方,2 位数码显示倒九秒提示。当机动车信号灯采用悬臂式杆件时,机动车信号灯倒计时器规格为800×600,当采用立柱式杆件时,倒计时器规格为400×400。人行信号灯倒计时显示器透光面为Φ300mm 或300mm ×300mm。倒计时显示器的光学性能、工作条件、机械强度、电气性能均符合国家安全行业标准GA/T508-2004《道路交通信号倒计时显示器》的全部技术规定。

2、倒计时器运行中遇到电磁、静电、电网等干扰时不能有死机现象

3、倒计时器必须经过过电压、过电流测试,具有防雷击功能

4、倒计时器应为学习型,并支持脉冲触发、黄灯触发及通讯式触发

## 信号灯灯杆

1、信号灯杆所属的立柱、法兰盘、地脚螺栓、螺母、垫片、加强筋等金属构件及悬臂、支撑臂、拉杆、抱箍座、夹板等附件的防腐性能应符合GB/T18226《公路交通工程钢构件防腐技术条件》的规定。

2、信号灯杆应采用圆形或多棱形经热镀锌处理的钢管制造;悬臂式灯杆悬臂杆与支撑杆使用圆形或多棱形的变截面型材制作,悬臂与灯杆连接端宜焊接固定法兰盘,悬臂下应留有进出线孔。

3、信号灯杆制作后须经过防锈处理,底层喷涂富锌防锈底漆,外层喷涂银灰色瓷漆

4、信号灯灯杆距路面约300-350mm 处留有拉线孔和拉线孔门

5、孔门盖应设有防盗措施,孔内设置接地端子座,并与接地线可靠接驳

6、立柱式灯杆顶部安装灯具处应留有出线孔,并配备橡胶护套、电缆线回水弯挂钩灯杆顶部应安装塑料或经防腐处理的内套式金属防水管帽。

7、悬臂式灯杆拉杆宜使用圆钢制作,一端配有可调距离的螺旋扣,直径和长度根据悬臂长度确定。

8、信号灯杆杆体底部应焊接固定法兰盘,法兰盘与杆体之间应均匀焊接加强筋

9、一体式人行信号灯采用整灯嵌入式设计、结构紧凑、方便拆装、便于维护。杆体前后金属面板喷塑处理,两侧铝型材包边。

## 交通信号机

★应采用区域控制信号机,并应与广水市交通信号控制系统兼容,信号机能接入已有系统平台,实现联网优化功能。

## 1、控制功能

(1)区域协调控制:可对单个孤立交叉口、干道多个交叉口和关联性较强的交叉口群进行综合性地信号控制。

2)线性协调控制:可对干道多个相邻交叉口进行协调控制

(3)多时段控制:可根据交叉口的交通状况,将每天划分为多个不同的时段,每个时段配置不同的控制方案,能设置至少10 个时段、10 种以上不同控制方案,能根据不同周日类型对方案进行调整。信号机能够根据内置时钟选择各个时段的控制方案,实现交叉口的合理控制。

(4)感应控制:信号机能根据检测到车辆达到情况,在保证最小安全绿灯时间的前提下,调整感应方向的绿信比参数,实现路口的最佳配时,保证交叉口的通行顺畅。通过参数配置,在感应方向没有机动车请求的情况下,信号机能够跳过感应相位,直接放行下一相位。

(5)单点优化控制:信号机能根据检测的交通流信息,适当调整路口周期时长和绿信比分配,实现路口信号控制的最优方案。

(6)无缆线协调控制:信号机能够通过配置路口相位差,即使在不联网的条件下,依然实现各个路口的绿波协调控制效果。

(7)手动控制:在某些特殊情况下,使用者可以通过手动装置完成手动强制功能,使信号显示停留在任意相位(包括全红、黄闪);信号机也可响应来自监控中心操作终端或现场笔记本的手动控制指令。

(8)黄闪控制:信号机具有黄闪控制功能,可以通过手动控制实现黄闪,或者通过规定时段自动进入黄闪控制。另外,当信号机的硬件发生故障时,可以进入硬件故障黄闪。

(9)全红控制:信号机能够根据时间表调用信号机的全红控制方案,实现对交叉口的全红控制功能。路口信号机具备一键全红功能,即:触动信号机某一按钮即实现路口全红控制,该按钮应设置在手控箱中便于操作。中心控制软件具备一键全红功能,用法同上。

(10)公交优先控制:支持RFID、地磁、线圈等检测方式,支持多种公交优先控制策略。

11)黑灯:能够一键关闭所有信号灯。

(12)行人过街按钮:信号机支持行人按钮信号输入,可在路口和路段响应来自行人按钮的行人过街请求。

(13)溢出控制:信号机发现路口拥堵后,能够立即调整绿灯时间或其他指定灯色的方式,避免过多车辆涌入拥堵方向或快速放行,抑制拥堵扩散(或溢出)或加速疏导。

14)相位控制:至少8 个相位控制,可扩至16 个以上相位控制。

15)信号灯组输出:至少8 个独立信号组输出,可扩展至16 个以上独立信号组输出

## 2、采集功能

1)信号机支持接入线圈、地磁、视频、微波、超声波检测器、RFID 等多种检测方式

2)信号机支持交通信息采集与统计,并支持交通流量共享

## 3、运维功能

1)信号机能够自动检测地磁故障,若故障,能够自动上传故障信息至监控中心

(2)具有故障自检功能,如信号机死机时迅速做出反应重新启动信号机;出现绿灯冲突时,马上切换到黄闪状态,对绿灯冲突进行检测和处理,并记录绿灯冲突的灯组;对信号灯驱动部分和外线出现的故障以及信号机各主要部件的故障进行自动检测和记录。

(3)信号机支持检测机柜内电压状态指标,若出现异常情况,能够及时报警并上传中心控制系统。

(4)信号机主控板一旦发生故障后,信号机仍能够继续运行定周期方案,保障路口交通秩序,等待主控板故障排除后,自动恢复。

(5)信号机出现故障时应能按“上位机控制→无电缆协调控制→感应控制→定时控制→黄闪”实现降级。

## 4、通信功能

1)交通信号控制器支持有线、无线联网

(2)交通信号控制机应基于开放的通信协议,满足《交通信号控制机与上位机间的数据通信协议》(GB/T20999-2017)标准或NTCIP 通讯协议体系架构,符合度≥90%。

## 5、操作功能

(1)交通信号控制器必须提供维护软件,支持通过串口、网口连接。信号机侧面具备手动控制面板,能够在现场进行手动控制。

湖北众恒永业工程项目管理有限公司广水分公司编制

## 6、其他功能

(1)机动车灯按顺序的转换过程中无显示中断现象。人行横道灯绿灯时间能够灵活确定。绿闪、黄灯、全红时间设置为0 时,该灯色不应出现,且不会影响信号的正常转换。

(2)信号机从自动控制方式转入手动控制方式时,信号机应保持原有相位的最小安全时间,最小安全时间可根据路口实际情况设定;从手动控制方式(驻留或步进)转入自动控制方式时,信号状态不会突变,各相位信号应保持转换时刻的状态,至少保持最小安全时间。

(3)信号机采用的芯片具有精确的时钟,与中心系统联接后,系统可定时校准信号机时钟,采用具有时、分、秒、年、月、日、星期的晶体时钟计时,保证信号机时钟精度在1秒内。若信号机不与中心连接,配置GPS 接口,可通过GPS 接口进行精确的时钟校准,保证时钟分秒无差。停电时由电池保持时钟继续工作,采用锂电池作为后备电源。

(4)停电保护功能:自动保存修改的各项控制参数,停电后数据不会丢失。质保期:2年。

## 交通监控视频子系统

## 系统功能

## 1)高清录像功能

▲系统能实现24 小时高清视频录像功能。可以在白天或夜间有辅助光源的情况下实现清晰录像;视频编码格式至少支持H.264/ H.265;可自动记录车辆通过时间、地点、所在车道、违法类型等信息;录像中能清晰地反映车辆的颜色、车辆类型、运动轨迹,并提供录像查询、下载等功能。

## 2)云镜控制功能

▲至少具备监控前端设备切换、云台/快球控制器方向控制、焦距调节、镜头缩放、光圈调节、预置位设置、雨刷和电源开关控制、自定义辅助开关控制、监控前端设备锁定与解锁、云台/快球控制器的参数设定等功能。

3)巡检预警功能

系统可对城市进行全面综合交通视频监控;通过交通视频监控系统的巡检功能,定时不间断地对城市进行全面监控扫描。值班人员可以根据图像画面上所发出的报警信息,及时定点跟踪确认。第一时间进行力量调度,并对事件的发展情况和事态的全程变化状况全程跟踪、

实时录像、调查取证

## 4)警情核实功能

利用交通视频监控系统,可以准确地对城市报警情况进行核实。当接到报警信息后,可以将摄像头调整到报警位置,进行识别判断;确认报警信息是否属实。

## 5)救援指挥功能

交通视频监控系统由于位置高、监控距离远、视角广的特点,在发生某些特定事件救援时,可以有效地对救援点交通进行一个诊断,减少或者避免由于客观原因造成的事态扩大。

## 6)车辆布控功能

▲设备具备车辆布控功能,当监视画面中出现布控名单中的机动车时,设备可触发报警并跟踪,布控名单中可添加10000 个号牌信息

## 一体化高速球机

1 ▲用≥1.8 英寸红外型800 万像素逐行扫描图像传感器

2、光学变倍≥22 倍,焦距≥6.5\~143mm,支持H.265、H.264、MJPEG 视频编码

3、分辨率≥3840×2160,喷率≥30fpS,,亮度等级≥11 级

4、支持超低照度监控:彩色模式≤0.01lx,黑白模式≤0.003lx,具备三码流功能:主码流3840×2160、30 帧/秒、8Mbps;子码流1280×720、30 帧/秒、1Mbps;第三码流主码流3840×2160、30 帧/秒、1Mbps,码率设置为128Kbps\~8Mbps。

5、摄像机具备自动增益控制功能、自动白平衡调整功能、逆光补偿调整功能、日夜模式、电子快门、自动聚焦、断电记忆、定时启动、区域遮盖、自动定位、在线升级、断线自动重连。

6、▲支持前端存储功能

7、支持360°水平连续旋转,支持垂直-15°\~90°旋转

8、摄像机具备良好的电源适应性,在AC24±35%或DC24±35%范围内,能正常工作IP 防护等级≥IP67,环境温度满足-45\~70℃。

## 光纤收发器

1、1 路千兆以太网

2、单模单纤,光接口为FC 接口,满足实际传输距离要求

3、10/100/1000M 自适应以太网接口。

4、工作环境适应性强,满足全天候使用的要求

5、耐压≥300V

## 交通诱导子系统

# 交通诱导屏

1、主要特性

1)温度范围-40\~70℃

2)光带宽度&gt;130mm

3)通迅接口:RS485、网络通讯、3G 网络

4)视角:水平:110°\~120° 垂直:55°

5)发光亮度:6500-7000 cd/m2

6)平整度≤0.5mm

7)使用寿命≥10 万小时

8)平均故障时间≥1 万小时

9)电源采用n+1 高可靠容错的开关电源系统

10) 显示尺寸:长3.84 米×高2.56 米=9.83 平方米

11) 机箱要求:冷轧钢板,机箱为内外两层,内箱体为全封闭、全天候、防风雨型,符

合IP65 防护等级

12) 抗风等级:40m/s

2、技术参数

1)物理点间距:10mm

2)物理密度:10000 点/m2

3)发光点颜色:1R1G

4)基色:纯红+纯绿

5)模组尺寸:320mm*160mm

6)刷新频率:≥800HZ

7)工作电压:AC220V±10%,50Hz(三相五线制

8)平均功耗:350W/m2

9)最大功耗:≤700W/ m2

## 电子警察子系统

## 系统功能

## 1)闯红灯违法抓拍功能

★系统可以实现对单方向各车道闯红灯车辆的监测、图像抓拍等功能。闯红灯捕获率≥90%,每一违法记录拍摄连续3 张反映闯红灯过程的图片,其中第一个位置的图片反映机动车未到达停止线的情况,并能清晰辨别车辆类型、交通信号灯红灯、停止线;第二个位置的图片反映机动车已越过停止线的情况,并能清晰辨别车辆类型、号牌号码、交通信号灯红灯、停止线;第三个位置的图片反映机动车越过停止线继续前行的情况,并能清晰辨别车辆类型、交通信号灯红灯、停止线。

## 2)不按车道行驶记录功能

当车辆遇到“分向行驶车道”不按规定的转向、右转车辆占用直行车道,或在左转、右转车道上直行等情形,系统可以实现对此类违法行为的记录,以三张图片清晰、完整表现违法过程。

## 3)违章变道记录功能

▲系统能够对违法变道车辆进行记录,抓拍三张不同位置的图片以反映整个违法变道过程,其中第一张为车辆在初始车道行驶时抓拍的图片,第二张为压线行驶时抓拍的图片,第三张为变换到另一个车道上行驶时抓拍的图片。

## 4)闯禁令记录功能

系统能够对违反禁左、禁右、禁止掉头等通行的车辆,进行检测、抓拍记录与识别

## 5)卡口监测记录功能

系统能够准确捕获、记录车辆通行信息(车辆尾部的图片),对通过车辆的捕获率不小于99%。记录的车辆信息除包含图像信息外,还包括文本信息,如日期、时间(精确到秒)、地点、方向、号牌号码等。车辆信息写入关联数据库,并将相关文本信息叠加到图片上。

## 6)逆行记录功能

系统能够对逆向行驶的违法车辆进行检测、抓拍记录与识别

## 7)压线行驶记录功能

系统能够对压线行驶的违法车辆进行检测、抓拍记录与识别,其主要针对在连续一段时

间内压车道线行驶的车辆,此类车辆会影响前后车驾驶员的判断,干扰前后车的正常形式。

## 8)车身颜色识别功能

▲系统能够自动对车身深浅和颜色进行识别,可供用户根据车身颜色来查询通行车辆

## 9)车牌号码自动识别

系统能够对符合“GA36-2014”标准的民用车牌、新能源车辆、警用车牌、使领馆车牌的号牌自动识别能力。

## 10)图像防纂改功能

记录的原始图像信息具备防纂改功能,避免在传输存储、处理等过程中被认为篡改

## 11)测速功能

系统能够与测速设备配套使用,监控车辆行驶的速度,对超速行驶的车辆进行抓拍

## 12)未系安全带检测功能

★采用视频检测技术,对未系安全带行为进行检测,抓拍记录与识别

## 13)接打电话检测功能

采用视频检测技术,实现对前排驾驶人接打电话状态的检测,抓拍记录与识别

## 14)驾驶人面部特征记录功能

★在电子警察杆件上增加车辆正向采集的摄像机,可通过路口终端服务器实现驾驶人面部特征记录功能。可将违法行为与对应车辆的正向图片匹配起来,从而将违法行为固定到驾驶人,有效遏制驾驶分非法买卖现象,同时为公安交通管理和刑侦案件侦破提供技术支持。

## 15)车辆稽查布控功能

系统具备车辆交通安全违法行为监测报警和布控车辆自动比对报警功能,比对方式包括精确比对和模糊比对。

## 16)交通流量数据采集功能

系统能够按车道和时段进行车辆流量、平均速度、车辆类型、占有率、平均车头时距、平均排队长度、饱和度等数据的统计。所有统计数据应支持以报表形式输出。

## 17)高清录像功能

系统支持道路交通情况的实时视频录像存储,视频质量能清晰反映覆盖区域内行驶机动车的车牌号码。视频采用预分配存储机制,前端支持进行滚动存储7 天以上。

## 18)数据断点续传功能

系统支持断点续传功能。当遇到网络中断或其他故障时,车辆信息存储在前端设备中待故障排除后自动续传。

湖北众恒永业工程项目管理有限公司广水分公司编制

## 19)时间校准功能

按照《GA/T832-2014 道路交通安全违法行为图像取证技术规范》的要求,24h 内计时误差不超过1.0s,确保所有前端设备点位每日至少与电子警察中心系统时钟同步一次。

## 20)网络远程维护功能

系统可以实时查看前端设备的运行状态。能通过网络实现远程维护、远程设置和远程升级等功能。

## 20)黑白名单功能

▲系统支持车牌黑/白名单设置,最大可设置60 万条黑/白名单

## 21)连续闯红灯监测功能

▲支持连续闯红灯事件检测功能,对某一时间段内连续闯红灯事件进行检测,并自动上传报警信息。

## 高清视频摄像机

高清视频摄像机为核心产品

<table border="1" ><tr>
<td colspan="1" rowspan="1">序号</td>
<td colspan="2" rowspan="1">指标项</td>
<td colspan="1" rowspan="1">技术规格要求</td>
</tr><tr>
<td colspan="1" rowspan="4">1 </td>
<td colspan="1" rowspan="4">摄像机</td>
<td colspan="1" rowspan="1">有效像素</td>
<td colspan="1" rowspan="1">≥900W 像素</td>
</tr><tr>
<td colspan="1" rowspan="1">最低照度</td>
<td colspan="1" rowspan="1">彩色≤0.001lx</td>
</tr><tr>
<td colspan="1" rowspan="1">传感器类型</td>
<td colspan="1" rowspan="1">≥1 英寸全局曝光COMS/GMOS/GS COMS </td>
</tr><tr>
<td colspan="1" rowspan="1">电子快门</td>
<td colspan="1" rowspan="1">至少满足1/25s 至1/100,000s,可调</td>
</tr><tr>
<td colspan="1" rowspan="3">2 </td>
<td colspan="1" rowspan="6">视频图像</td>
<td colspan="1" rowspan="1">视频压缩标准</td>
<td colspan="1" rowspan="1">至少支持H264、H265 等</td>
</tr><tr>
<td colspan="1" rowspan="1">视频分辨率</td>
<td colspan="1" rowspan="1">≥4096×2160,向下可设置</td>
</tr><tr>
<td colspan="1" rowspan="1">视频流帧率</td>
<td colspan="1" rowspan="1">≥25fps,至少双视频流</td>
</tr><tr>
<td colspan="1" rowspan="3">3 </td>
<td colspan="1" rowspan="1">图片压缩方式</td>
<td colspan="1" rowspan="1">JPEG </td>
</tr><tr>
<td colspan="1" rowspan="1">图像分辨率</td>
<td colspan="1" rowspan="1">≥4096(H)×2160(V)</td>
</tr><tr>
<td colspan="1" rowspan="1">强光抑制</td>
<td colspan="1" rowspan="1">具备</td>
</tr><tr>
<td colspan="1" rowspan="1">4 </td>
<td colspan="1" rowspan="1">协议</td>
<td colspan="1" rowspan="1">API 接口开放</td>
<td colspan="1" rowspan="1">▲具备;支持标准ONVIF 协议与第三方厂家设备进行互联;支持GB/T28181;应提供SDK </td>
</tr><tr>
<td colspan="1" rowspan="4">5 </td>
<td colspan="1" rowspan="2">接口</td>
<td colspan="1" rowspan="1">通讯接口</td>
<td colspan="1" rowspan="1">≥1 个RJ45,10M/100M/1000M 自适应以太网电口;≥1 个RS-485 接口</td>
</tr><tr>
<td colspan="1" rowspan="1">前端存储卡</td>
<td colspan="1" rowspan="1">嵌入式,支持断网时本地存储,裸容量≥128GB </td>
</tr><tr>
<td colspan="1" rowspan="2">功能</td>
<td colspan="1" rowspan="2">具备其他功能</td>
<td colspan="1" rowspan="1">应具备I/O 触发、RS-485 触发、视频触发,支持电源同步;支持频闪式卜光装置和脉冲式补光装置同步补光</td>
</tr><tr>
<td colspan="1" rowspan="1">具备AI 深度学习算法和GPU 芯片</td>
</tr><tr>
<td colspan="1" rowspan="1">6 </td>
<td colspan="1" rowspan="1">高清工业级镜头</td>
<td colspan="1" rowspan="1">光圈、聚焦</td>
<td colspan="1" rowspan="1">手动光圈;焦距应可根据车道宽度及抓拍距离进行调整设置,要求中心成像圆内解像力不小于900 万像素,边缘解像力不低于中心60%,镜头的成像尺寸应与摄像机成像靶面尺寸相等或略大。镜头应配置电动偏振镜,具</td>
</tr><tr>
<td colspan="1" rowspan="1"></td>
<td colspan="1" rowspan="1"></td>
<td colspan="1" rowspan="1"></td>
<td colspan="1" rowspan="1">备根据环境自动切换功能</td>
</tr><tr>
<td colspan="1" rowspan="2">7 </td>
<td colspan="1" rowspan="2">防护罩</td>
<td colspan="1" rowspan="1">防护罩类型</td>
<td colspan="1" rowspan="1">室外型防护罩,含底座;具备隔热防潮、防水、防尘、防腐、防震等功能;具有加热器、支架、遮阳罩等,具有良好的密封性和恒温等功能。</td>
</tr><tr>
<td colspan="1" rowspan="1">防护等级</td>
<td colspan="1" rowspan="1">≥IP66</td>
</tr></table>

LED 补光灯

<table border="1" ><tr>
<td colspan="1" rowspan="1">序号</td>
<td colspan="1" rowspan="1">指标项</td>
<td colspan="1" rowspan="1">技术参数要求</td>
</tr><tr>
<td colspan="1" rowspan="1">1 </td>
<td colspan="1" rowspan="1">配置方式</td>
<td colspan="1" rowspan="1">每个车道配置≥1 台;补光装置必须与高清摄像设备高度匹配</td>
</tr><tr>
<td colspan="1" rowspan="1">2 </td>
<td colspan="1" rowspan="1">LED 管芯</td>
<td colspan="1" rowspan="1">采用超高亮大功率白光LED 管芯,灯珠数量不少于20 颗</td>
</tr><tr>
<td colspan="1" rowspan="1">3 </td>
<td colspan="1" rowspan="1">功耗</td>
<td colspan="1" rowspan="1">30W/车道≤单台平均功耗≤50W/车道,可调</td>
</tr><tr>
<td colspan="1" rowspan="2">4 </td>
<td colspan="1" rowspan="1">峰值光照度</td>
<td colspan="1" rowspan="2">≤300lx</td>
</tr><tr>
<td colspan="1" rowspan="1">(基准轴)</td>
</tr><tr>
<td colspan="1" rowspan="2">5 </td>
<td colspan="1" rowspan="1">峰值光照度</td>
<td colspan="1" rowspan="2">应大于等于基准轴上有效光照度的50%</td>
</tr><tr>
<td colspan="1" rowspan="1">(补光区)</td>
</tr><tr>
<td colspan="1" rowspan="1">6 </td>
<td colspan="1" rowspan="1">平均光照度</td>
<td colspan="1" rowspan="1"></td>
</tr><tr>
<td colspan="1" rowspan="1">7 </td>
<td colspan="1" rowspan="1">闪光频率</td>
<td colspan="1" rowspan="1">;补光装置应能与集成式高清摄像设备同步</td>
</tr><tr>
<td colspan="1" rowspan="1">8 </td>
<td colspan="1" rowspan="1">有效补光距离</td>
<td colspan="1" rowspan="1">≥25m</td>
</tr><tr>
<td colspan="1" rowspan="1">9 </td>
<td colspan="1" rowspan="1">最大点亮时间</td>
<td colspan="1" rowspan="1">≤4ms(可调节)</td>
</tr><tr>
<td colspan="1" rowspan="1">10 </td>
<td colspan="1" rowspan="1">控制方式</td>
<td colspan="1" rowspan="1">电平,同步触发方式</td>
</tr><tr>
<td colspan="1" rowspan="1">11 </td>
<td colspan="1" rowspan="1">安全性</td>
<td colspan="1" rowspan="1">在保证瞬时亮度的前提下,必须进行防炫目处理,不会造成光污染</td>
</tr><tr>
<td colspan="1" rowspan="1">12 </td>
<td colspan="1" rowspan="1">使用寿命</td>
<td colspan="1" rowspan="1">≥50000 小时</td>
</tr><tr>
<td colspan="1" rowspan="1">13 </td>
<td colspan="1" rowspan="1">防护等级</td>
<td colspan="1" rowspan="1">不低于IP65 </td>
</tr><tr>
<td colspan="1" rowspan="1">14 </td>
<td colspan="1" rowspan="1">其它</td>
<td colspan="1" rowspan="1">应配置光栅装置或遮光阻断装置</td>
</tr></table>

## 光纤收发器

1、1 路千兆以太网

2、单模单纤,光接口为FC 接口,满足实际传输距离要求

3、10/100/1000M 自适应以太网接口。

4、工作环境适应性强,满足全天候使用的要求

5、耐压≥300V

## 交换机

1、交换容量≥6Gbps,包转发率≥7Mpps;MAC 地址列表≥8K;应具备线性转发能力;

2、应至少具有8 个10/100/1000M 自适应以太网接口和至少2 个1000M 光口

3、以太网光端口传输距离应不小于40km,以太网光模块为单芯双向光模块,光口接口类型为LC 型接口,光模块连接单模光纤;

4、至少支持IEEE802.1p、IEEE802.1q、IEEE802.3、IEEE802.3u、IEEE802.3z IEEE802.3x 等协议;

5、应具有IEEE802.1Q VLAN,应实现信号控制独立传输,至少支持4 个VLAN 划分;

6、应至少支持三层动态路由协议

7、应具有IEEE802.1p_QOS 功能

8、应具有IGMP 静态组播、端口聚合、端口镜像等功能

9、IP40 以上等级防护

10、应采用无风扇设计

11、应具有网管功能

## 红绿灯信号检测器

每路口配置1 套,至少能检测12 路独立红灯信号,红灯信号检测准确率为100%

## 终端服务器

1、结构形式:采用嵌入式架构

2、操作系统:嵌入式操作系统

3、▲接入路数:提供≥12 路高清摄像机视频存储、过车记录存储、图片存储、数据上传、视频流转发等;

4、主机存储:内置SATA 接口;配置存储容量≥16T 硬盘

5、网络接口:提供≥8 个RJ45 1000M 网络接口

6、其他接口:提供RS232、RS485、外置USB 接口、VGA 接口等

7、访问操作:支持Web 操作访问

8、▲接口协议:至少支持ONVIF,GB/T28181 等

9、API 接口开放支持;支持标准ONVIF 协议与第三方厂家设备进行互通;支持GB/T 28181。

10、▲支持套牌车检测,可将抓拍图片与本地历史数据进行车辆特征比对分析,检测出

套牌车辆,同时给出告警提示

## 交通卡口子系统

## 系统功能

对监控路段的车辆、车道进行全天候实时的监控并记录相关图像、视频数据。主要实现以下功能:

1)卡口记录功能:捕获正常行驶车辆的过车图片,抓拍率≥99%

2)逆行记录功能:对逆向行驶的违法车辆进行检测、抓拍记录与识别

(3)压线行驶记录功能:对压线行驶的违法车辆进行检测、抓拍记录与识别,其主要针对在连续一段时间内压车道线行驶的车辆,此类车辆会影响前后车驾驶员的判断,干扰前后车的正常行驶;

(4)车身颜色识别功能:可自动对车身深浅和颜色进行识别,可供用户根据车身颜色来查询通行车辆;

(5)车牌号码自动识别:对符合“GA36-2014”标准的民用车牌、新能源车辆、警用车牌、使领馆车牌的号牌自动识别能力;

(6)闯禁行记录功能:对违反禁止通行的车辆,进行检测、抓拍记录与识别;

(7)▲图像防纂改功能:记录的原始图像信息具备防纂改功能,避免在传输存储、处理等过程中被人为篡改;

(8)测速功能:与测速设备配套使用,监控车辆行驶的速度,对超速行驶的车辆进行抓拍;

(9)★未系安全带检测功能:采用视频检测技术,对未系安全带行为进行检测,抓拍记录与识别;

(10)接打电话检测功能:采用视频检测技术,实现对前排驾驶人接打电话状态的检测,抓拍记录与识别;

(11)★人脸特征抠图:采用视频检测技术对驾驶室人脸特征进行检测并将人脸特征抠出,为公安交通管理和刑侦案件侦破提供技术支持。

(12)▲支持混合抓拍模式,设备支持正面/侧面/背面行人(包括成年人和儿童)的抓拍;支持对骑自行车、骑三轮车、骑电动车、踩平衡车、骑车带人等

非机动车的抓拍;支持对轿车、客车、面包车、货车、卡车、摩托车等机动车的抓拍

高清视频抓拍像机

<table border="1" ><tr>
<td colspan="1" rowspan="1">序号</td>
<td colspan="2" rowspan="1">指标项</td>
<td colspan="1" rowspan="1">技术规格要求</td>
</tr><tr>
<td colspan="1" rowspan="4">1 </td>
<td colspan="1" rowspan="4">摄像机</td>
<td colspan="1" rowspan="1">有效像素</td>
<td colspan="1" rowspan="1">≥900W 像素</td>
</tr><tr>
<td colspan="1" rowspan="1">最低照度</td>
<td colspan="1" rowspan="1">彩色≤0.001lx</td>
</tr><tr>
<td colspan="1" rowspan="1">传感器类型</td>
<td colspan="1" rowspan="1">≥1 英寸全局曝光COMS/GMOS/GS COMS </td>
</tr><tr>
<td colspan="1" rowspan="1">电子快门</td>
<td colspan="1" rowspan="1">至少满足1/25s 至1/100,000s,可调</td>
</tr><tr>
<td colspan="1" rowspan="3">2 </td>
<td colspan="1" rowspan="6">视频图像</td>
<td colspan="1" rowspan="1">视频压缩标准</td>
<td colspan="1" rowspan="1">至少支持H264、H265 等</td>
</tr><tr>
<td colspan="1" rowspan="1">视频分辨率</td>
<td colspan="1" rowspan="1">≥4096×2160,向下可设置</td>
</tr><tr>
<td colspan="1" rowspan="1">视频流帧率</td>
<td colspan="1" rowspan="1">≥25fps,至少双视频流</td>
</tr><tr>
<td colspan="1" rowspan="3">3 </td>
<td colspan="1" rowspan="1">图片压缩方式</td>
<td colspan="1" rowspan="1">JPEG </td>
</tr><tr>
<td colspan="1" rowspan="1">图像分辨率</td>
<td colspan="1" rowspan="1">≥4096(H)×2160(V)</td>
</tr><tr>
<td colspan="1" rowspan="1">强光抑制</td>
<td colspan="1" rowspan="1">具备</td>
</tr><tr>
<td colspan="1" rowspan="1">4 </td>
<td colspan="1" rowspan="1">协议</td>
<td colspan="1" rowspan="1">API 接口开放</td>
<td colspan="1" rowspan="1">具备;支持标准ONVIF 协议与第三方厂家设备进行互联;支持GB/T28181;应提供SDK </td>
</tr><tr>
<td colspan="1" rowspan="4">5 </td>
<td colspan="1" rowspan="2">接口</td>
<td colspan="1" rowspan="1">通讯接口</td>
<td colspan="1" rowspan="1">≥1 个RJ45,10M/100M/1000M 自适应以太网电口;≥1个RS-485 接口</td>
</tr><tr>
<td colspan="1" rowspan="1">前端存储卡</td>
<td colspan="1" rowspan="1">嵌入式,支持断网时本地存储,裸容量≥128GB </td>
</tr><tr>
<td colspan="1" rowspan="2">功能</td>
<td colspan="1" rowspan="2">具备其他功能</td>
<td colspan="1" rowspan="1">应具备I/O 触发、RS-485 触发、视频触发,支持电源同步;支持频闪式卜光装置和脉冲式补光装置同步补光</td>
</tr><tr>
<td colspan="1" rowspan="1">具备AI 深度学习算法和GPU 芯片</td>
</tr><tr>
<td colspan="1" rowspan="1">6 </td>
<td colspan="1" rowspan="1">高清工业级镜头</td>
<td colspan="1" rowspan="1">光圈、聚焦</td>
<td colspan="1" rowspan="1">手动光圈;焦距应可根据车道宽度及抓拍距离进行调整设置,要求中心成像圆内解像力不小于900 万像素,边缘解像力不低于中心60%,镜头的成像尺寸应与摄像机成像靶面尺寸相等或略大。镜头应配置电动偏振镜,具备根据环境自动切换功能</td>
</tr><tr>
<td colspan="1" rowspan="2">7 </td>
<td colspan="1" rowspan="2">防护罩</td>
<td colspan="1" rowspan="1">防护罩类型</td>
<td colspan="1" rowspan="1">室外型防护罩,含底座;具备隔热防潮、防水、防尘、防腐、防震等功能;具有加热器、支架、遮阳罩等,具有良好的密封性和恒温等功能。</td>
</tr><tr>
<td colspan="1" rowspan="1">防护等级</td>
<td colspan="1" rowspan="1">≥IP66</td>
</tr></table>

## 补光灯

<table border="1" ><tr>
<td colspan="1" rowspan="1">序号</td>
<td colspan="1" rowspan="1">指标项</td>
<td colspan="1" rowspan="1">技术参数要求</td>
</tr><tr>
<td colspan="1" rowspan="1">1 </td>
<td colspan="1" rowspan="1">配置方式</td>
<td colspan="1" rowspan="1">每个车道配置≥1 台;补光装置必须与高清摄像设备高度匹配</td>
</tr><tr>
<td colspan="1" rowspan="1">2 </td>
<td colspan="1" rowspan="1">LED 管芯</td>
<td colspan="1" rowspan="1">采用超高亮大功率白光LED 管芯,灯珠数量不少于20 颗</td>
</tr><tr>
<td colspan="1" rowspan="1">3 </td>
<td colspan="1" rowspan="1">功耗</td>
<td colspan="1" rowspan="1">30W/车道≤单台平均功耗≤50W/车道,可调</td>
</tr><tr>
<td colspan="1" rowspan="2">4 </td>
<td colspan="1" rowspan="1">峰值光照度</td>
<td colspan="1" rowspan="2">≤300lx</td>
</tr><tr>
<td colspan="1" rowspan="1">(基准轴)</td>
</tr><tr>
<td colspan="1" rowspan="1">5 </td>
<td colspan="1" rowspan="1">峰值光照度</td>
<td colspan="1" rowspan="1">应大于等于基准轴上有效光照度的50%</td>
</tr></table>

湖北众恒永业工程项目管理有限公司广水分公司编制

<table border="1" ><tr>
<td colspan="1" rowspan="1">序号</td>
<td colspan="1" rowspan="1">指标项</td>
<td colspan="1" rowspan="1">技术参数要求</td>
</tr><tr>
<td colspan="1" rowspan="1"></td>
<td colspan="1" rowspan="1">(补光区)</td>
<td colspan="1" rowspan="1"></td>
</tr><tr>
<td colspan="1" rowspan="1">6 </td>
<td colspan="1" rowspan="1">平均光照度</td>
<td colspan="1" rowspan="1"></td>
</tr><tr>
<td colspan="1" rowspan="1">7 </td>
<td colspan="1" rowspan="1">闪光频率</td>
<td colspan="1" rowspan="1">光装置应能与集成式高清摄像设备同步</td>
</tr><tr>
<td colspan="1" rowspan="1">8 </td>
<td colspan="1" rowspan="1">有效补光距离</td>
<td colspan="1" rowspan="1">≥25m</td>
</tr><tr>
<td colspan="1" rowspan="1">9 </td>
<td colspan="1" rowspan="1">最大点亮时间</td>
<td colspan="1" rowspan="1">≤4ms(可调节)</td>
</tr><tr>
<td colspan="1" rowspan="1">10 </td>
<td colspan="1" rowspan="1">控制方式</td>
<td colspan="1" rowspan="1">电平,同步触发方式</td>
</tr><tr>
<td colspan="1" rowspan="1">11 </td>
<td colspan="1" rowspan="1">安全性</td>
<td colspan="1" rowspan="1">在保证瞬时亮度的前提下,必须进行防炫目处理,不会造成光污染</td>
</tr><tr>
<td colspan="1" rowspan="1">12 </td>
<td colspan="1" rowspan="1">使用寿命</td>
<td colspan="1" rowspan="1">≥50000 小时</td>
</tr><tr>
<td colspan="1" rowspan="1">13 </td>
<td colspan="1" rowspan="1">防护等级</td>
<td colspan="1" rowspan="1">不低于IP65 </td>
</tr><tr>
<td colspan="1" rowspan="1">14 </td>
<td colspan="1" rowspan="1">其它</td>
<td colspan="1" rowspan="1">应配置光栅装置或遮光阻断装置</td>
</tr></table>

## 闪光灯

1、色温范围5500±500K

2、补光距离16m\~30m

3、回电时间≤60ms,满足相机2 张连拍需求

4、闪光灯寿命&gt;500 万次

5、自带光敏控制,可根据环境亮度自动调节闪光强度

6、防护等级IP66

7、在-20℃\~70℃温度范围内均能正常工作

## 光纤收发器

1、1 路千兆以太网

2、单模单纤,光接口为FC 接口,满足实际传输距离要求

3、10/100/1000M 自适应以太网接口。

4、工作环境适应性强,满足全天候使用的要求

5、耐压≥300V

## 交换机

1、交换容量≥6Gbps,包转发率≥7Mpps;MAC 地址列表≥8K;应具备线性转发能力

2、应至少具有8 个10/100/1000M 自适应以太网接口和至少2 个1000M 光口

3、以太网光端口传输距离应不小于40km,以太网光模块为单芯双向光模块,光口接口类型为LC 型接口,光模块连接单模光纤;

4、至少支持IEEE802.1p、IEEE802.1q、IEEE802.3、IEEE802.3u、IEEE802.3z、IEEE802.3x

湖北众恒永业工程项目管理有限公司广水分公司编制

等协议

5、应具有IEEE802.1Q VLAN,应实现信号控制独立传输,至少支持4 个VLAN 划分

6、应至少支持三层动态路由协议

7、应具有IEEE802.1p_QOS 功能

8、应具有IGMP 静态组播、端口聚合、端口镜像等功能

9、IP40 以上等级防护

10、应采用无风扇设计

11、应具有网管功能

## 终端服务器

1、结构形式:采用嵌入式架构

2、操作系统:嵌入式操作系统

3、接入路数:提供≥12 路高清摄像机视频存储、过车记录存储、图片存储、数据上传、视频流转发等;

4、主机存储:内置SATA 接口;配置存储容量≥16T 硬盘

5、网络接口:提供≥8 个RJ45 1000M 网络接口

6、其他接口:提供RS232、RS485、外置USB 接口、VGA 接口等

7、访问操作:支持Web 操作访问

8、接口协议:至少支持ONVIF,GB/T28181 等

9、API 接口开放支持;支持标准ONVIF 协议与第三方厂家设备进行互通;支持GB/T 28181。

## 区间测速子系统

## 系统功能

1)卡口记录功能:捕获正常行驶车辆的过车图片,抓拍率≥95%

2)逆行记录功能:对逆向行驶的违法车辆进行检测、抓拍记录与识别

(3)压线行驶记录功能:对压线行驶的违法车辆进行检测、抓拍记录与识别,其主要针对在连续一段时间内压车道线行驶的车辆,此类车辆会影响前后车驾驶员的判断,干扰前后车的正常形式;

(4)车身颜色识别功能:可自动对车身深浅和颜色进行识别,可供用户根据车身颜色来查询通行车辆;

(5)车牌号码自动识别:对符合“GA36-2014”标准的民用车牌、新能源车辆、警用车牌、使领馆车牌的号牌自动识别能力;

(6)▲闯禁行记录功能:对违反禁止通行的车辆,进行检测、抓拍记录与识别;

(7)图像防纂改功能:记录的原始图像信息具备防纂改功能,避免在传输存储、处理等过程中被认为篡改;

(8)★测速功能:与测速设备配套使用,监控车辆行驶的速度,对超速行驶的车辆进行抓拍;

(9)未系安全带检测功能:采用视频检测技术,对未系安全带行为进行检测,抓拍记录与识别;

(10)接打电话检测功能:采用视频检测技术,实现对前排驾驶人接打电话状态的检测,抓拍记录与识别;

(11)人脸特征抠图:采用视频检测技术对驾驶室人脸特征进行检测,并将人脸特征抠出,为公安交通管理和刑侦案件侦破提供技术支持。

高清视频抓拍像机

<table border="1" ><tr>
<td colspan="1" rowspan="1">序号</td>
<td colspan="2" rowspan="1">指标项</td>
<td colspan="1" rowspan="1">技术规格要求</td>
</tr><tr>
<td colspan="1" rowspan="4">1 </td>
<td colspan="1" rowspan="4">摄像机</td>
<td colspan="1" rowspan="1">有效像素</td>
<td colspan="1" rowspan="1">≥900W 像素</td>
</tr><tr>
<td colspan="1" rowspan="1">最低照度</td>
<td colspan="1" rowspan="1">彩色≤0.001lx</td>
</tr><tr>
<td colspan="1" rowspan="1">传感器类型</td>
<td colspan="1" rowspan="1">≥1 英寸全局曝光COMS/GMOS/GS COMS </td>
</tr><tr>
<td colspan="1" rowspan="1">电子快门</td>
<td colspan="1" rowspan="1">至少满足1/25s 至1/100,000s,可调</td>
</tr><tr>
<td colspan="1" rowspan="3">2 </td>
<td colspan="1" rowspan="6">视频图像</td>
<td colspan="1" rowspan="1">视频压缩标准</td>
<td colspan="1" rowspan="1">至少支持H264、H265 等</td>
</tr><tr>
<td colspan="1" rowspan="1">视频分辨率</td>
<td colspan="1" rowspan="1">≥4096×2160,向下可设置</td>
</tr><tr>
<td colspan="1" rowspan="1">视频流帧率</td>
<td colspan="1" rowspan="1">≥25fps,至少双视频流</td>
</tr><tr>
<td colspan="1" rowspan="3">3 </td>
<td colspan="1" rowspan="1">图片压缩方式</td>
<td colspan="1" rowspan="1">JPEG </td>
</tr><tr>
<td colspan="1" rowspan="1">图像分辨率</td>
<td colspan="1" rowspan="1">≥4096(H)×2160(V)</td>
</tr><tr>
<td colspan="1" rowspan="1">强光抑制</td>
<td colspan="1" rowspan="1">具备</td>
</tr><tr>
<td colspan="1" rowspan="1">4 </td>
<td colspan="1" rowspan="1">协议</td>
<td colspan="1" rowspan="1">API 接口开放</td>
<td colspan="1" rowspan="1">具备;支持标准ONVIF 协议与第三方厂家设备进行互联;支持GB/T28181;应提供SDK </td>
</tr><tr>
<td colspan="1" rowspan="2">5 </td>
<td colspan="1" rowspan="2">接口</td>
<td colspan="1" rowspan="1">通讯接口</td>
<td colspan="1" rowspan="1">≥1 个RJ45,10M/100M/1000M 自适应以太网电口;≥1个RS-485 接口</td>
</tr><tr>
<td colspan="1" rowspan="1">前端存储卡</td>
<td colspan="1" rowspan="1">嵌入式,支持断网时本地存储,裸容量≥128GB </td>
</tr><tr>
<td colspan="1" rowspan="2"></td>
<td colspan="1" rowspan="2">功能</td>
<td colspan="1" rowspan="2">具备其他功能</td>
<td colspan="1" rowspan="1">应具备I/O 触发、RS-485 触发、视频触发,支持电源同步;支持频闪式卜光装置和脉冲式补光装置同步补光</td>
</tr><tr>
<td colspan="1" rowspan="1">具备AI 深度学习算法和GPU 芯片</td>
</tr><tr>
<td colspan="1" rowspan="1">6 </td>
<td colspan="1" rowspan="1">高清工业级镜头</td>
<td colspan="1" rowspan="1">光圈、聚焦</td>
<td colspan="1" rowspan="1">手动光圈;焦距应可根据车道宽度及抓拍距离进行调整设置,要求中心成像圆内解像力不小于900 万像素,边缘解像力不低于中心60%,镜头的成像尺寸应与摄像机成像靶面尺寸相等或略大。镜头应配置电动偏振镜,具备根据环境自动切换功能</td>
</tr><tr>
<td colspan="1" rowspan="2">7 </td>
<td colspan="1" rowspan="2">防护罩</td>
<td colspan="1" rowspan="1">防护罩类型</td>
<td colspan="1" rowspan="1">室外型防护罩,含底座;具备隔热防潮、防水、防尘、防腐、防震等功能;具有加热器、支架、遮阳罩等,具有良好的密封性和恒温等功能。</td>
</tr><tr>
<td colspan="1" rowspan="1">防护等级</td>
<td colspan="1" rowspan="1">≥IP66</td>
</tr></table>

## 补光灯

<table border="1" ><tr>
<td colspan="1" rowspan="1">序号</td>
<td colspan="1" rowspan="1">指标项</td>
<td colspan="1" rowspan="1">技术参数要求</td>
</tr><tr>
<td colspan="1" rowspan="1">1 </td>
<td colspan="1" rowspan="1">配置方式</td>
<td colspan="1" rowspan="1">每个车道配置≥1 台;补光装置必须与高清摄像设备高度匹配</td>
</tr><tr>
<td colspan="1" rowspan="1">2 </td>
<td colspan="1" rowspan="1">LED 管芯</td>
<td colspan="1" rowspan="1">采用超高亮大功率白光LED 管芯,灯珠数量不少于20 颗</td>
</tr><tr>
<td colspan="1" rowspan="1">3 </td>
<td colspan="1" rowspan="1">功耗</td>
<td colspan="1" rowspan="1">30W/车道≤单台平均功耗≤50W/车道,可调</td>
</tr><tr>
<td colspan="1" rowspan="2">4 </td>
<td colspan="1" rowspan="1">峰值光照度</td>
<td colspan="1" rowspan="2">≤300lx</td>
</tr><tr>
<td colspan="1" rowspan="1">(基准轴)</td>
</tr><tr>
<td colspan="1" rowspan="2">5 </td>
<td colspan="1" rowspan="1">峰值光照度</td>
<td colspan="1" rowspan="2">应大于等于基准轴上有效光照度的50%</td>
</tr><tr>
<td colspan="1" rowspan="1">(补光区)</td>
</tr><tr>
<td colspan="1" rowspan="1">6 </td>
<td colspan="1" rowspan="1">平均光照度</td>
<td colspan="1" rowspan="1"></td>
</tr><tr>
<td colspan="1" rowspan="1">7 </td>
<td colspan="1" rowspan="1">闪光频率</td>
<td colspan="1" rowspan="1">补光装置应能与集成式高清摄像设备同步</td>
</tr><tr>
<td colspan="1" rowspan="1">8 </td>
<td colspan="1" rowspan="1">有效补光距离</td>
<td colspan="1" rowspan="1">≥25m</td>
</tr><tr>
<td colspan="1" rowspan="1">9 </td>
<td colspan="1" rowspan="1">最大点亮时间</td>
<td colspan="1" rowspan="1">≤4ms(可调节)</td>
</tr><tr>
<td colspan="1" rowspan="1">10 </td>
<td colspan="1" rowspan="1">控制方式</td>
<td colspan="1" rowspan="1">电平,同步触发方式</td>
</tr><tr>
<td colspan="1" rowspan="1">11 </td>
<td colspan="1" rowspan="1">安全性</td>
<td colspan="1" rowspan="1">在保证瞬时亮度的前提下,必须进行防炫目处理,不会造成光污染</td>
</tr><tr>
<td colspan="1" rowspan="1">12 </td>
<td colspan="1" rowspan="1">使用寿命</td>
<td colspan="1" rowspan="1">≥50000 小时</td>
</tr><tr>
<td colspan="1" rowspan="1">13 </td>
<td colspan="1" rowspan="1">防护等级</td>
<td colspan="1" rowspan="1">不低于IP65 </td>
</tr><tr>
<td colspan="1" rowspan="1">14 </td>
<td colspan="1" rowspan="1">其它</td>
<td colspan="1" rowspan="1">应配置光栅装置或遮光阻断装置</td>
</tr></table>

## 闪光灯

1、色温范围5500±500K

2、补光距离16m\~30m

3、回电时间≤60ms,满足相机2 张连拍需求

4、闪光灯寿命&gt;500 万次

5、自带光敏控制,可根据环境亮度自动调节闪光强度

6、防护等级IP66

7、在-20℃\~70℃温度范围内均能正常工作

## 光纤收发器

1、1 路千兆以太网

2、单模单纤,光接口为FC 接口,满足实际传输距离要求

3、10/100/1000M 自适应以太网接口。

4、工作环境适应性强,满足全天候使用的要求

5、耐压≥300V

## 交换机

1、交换容量≥6Gbps,包转发率≥7Mpps;MAC 地址列表≥8K;;应具备线性转发能力

2、应至少具有8 个10/100/1000M 自适应以太网接口和至少2 个1000M 光口

3、以太网光端口传输距离应不小于40km,以太网光模块为单芯双向光模块,光口接口类型为LC 型接口,光模块连接单模光纤;

4、至少支持IEEE802.1p、IEEE802.1q、IEEE802.3、IEEE802.3u、IEEE802.3z、IEEE802.3x 等协议;

5、应具有IEEE802.1Q VLAN,应实现信号控制独立传输,至少支持4 个VLAN 划分

6、应至少支持三层动态路由协议

7、应具有IEEE802.1p_QOS 功能

8、应具有IGMP 静态组播、端口聚合、端口镜像等功能

9、IP40 以上等级防护

10、应采用无风扇设计

11、应具有网管功能

## 终端服务器

1、结构形式:采用嵌入式架构

2、操作系统:嵌入式操作系统

3、接入路数:提供≥8 路高清摄像机视频存储、过车记录存储、图片存储、数据上传视频流转发等;

4、主机存储:内置SATA 接口;配置存储容量≥16T 硬盘

5、网络接口: 提供≥8 个RJ45 1000M 网络接口

6、其他接口:提供RS232、RS485、外置USB 接口、VGA 接口等

7、访问操作:支持Web 操作访问

8、接口协议:至少支持ONVIF,GB/T28181 等

9、API 接口开放支持;支持标准ONVIF 协议与第三方厂家设备进行互通;支持GB/T 28181。

## 后台

## 接入服务器

1、机架式服务器

2、处理器:至少配置2 颗单颗10 核CPU,单核CPU 主频≥2.0GHz;

3、内存:配置128GB DDR4 内存

4、硬盘:配置6 块1.2T SAS 硬盘,转速≥10Krpm

5、RAID:配置RAID 控制器,支持RAID0、1、10、1E、5、50、60 等

6、网络:配置双千兆网卡

7、电源:双电源

## 存储服务器

1、4U 48 盘位磁盘阵列

2、单设备配置64 位多核处理器

3、16GB 缓存

4、冗余电源

5、支持SATA 硬盘

6、2 个千兆网口

7、1 个系统SSD 盘

8、支持视音频、图片、直接写入,支持视频高速预览、回放、下载,支持云内容灾备份,支持一体化运维,支持GB/T28181-2011、Onvif、RTSP、H265、SVAC 等标准视频协议。

## 硬盘

4T,3.5 寸,SATA

# 其他设备要求

# 室外挂箱

1、采用悬挂式安装方式,悬挂于杆件立柱,高度应确保机箱下边缘距离地面净高2.5米以上。设备机箱安装后不得侵入机动车道建筑界限以内,不得影响车辆正常通行。设备机箱应安装牢固;

2、设备机箱表面应经过考漆处理,应具备防锈蚀、防盐雾、防霉菌能力

3、应能摆放通信接入端设备。机箱内部空间应足够大,能确保设备、装置的合理摆放,设有存放用户手册、说明书、接线图、维修记录等资料的存储盒,并有适当空间预留。机箱空间应有利于机箱内各设备单元的散热、安装、使用和维修,同时应提供设备辅助散热措施,提高系统环境适应能力;

4、设备机箱的结构应能防雨并能降低灰尘及有害物质的侵入,机箱门盖应有溢水槽机箱门内侧应配备密封条,机箱顶部应具有防积水措施。机箱防护等级应达到IP55 以上;

5、机箱结构应具有足够的机械强度,应能承受正常条件下可预料到的运输、安装、搬运、维护等过程中的操作;

6、机箱门的最大开启角度应大于120°。机箱门锁应采用保险柜天地锁式的结构设计防止被非法打开,门锁至少可对上、下及左右侧中的一侧进行缩栓式保护,应具备较强的设备防砸、防盗能力。机箱应具有防盗报警功能,机箱在非正常状态下开启时能够报警提示。机箱门接缝处有耐久且有弹性的密封垫,密封垫连续设置,无间断接口。机柜门锁上后,无松动、变形现象;

7、设备机箱内设应置有具备稳压、过载、漏电、短路保护功能的电源开关和防雷保护功能的电源浪涌保护器。在熔断器和电源开关等处应有警告标志。机箱内合适位置配备接地铜排,接地铜排的截面应不小于100 mm2,接地端子应进行防腐处理。并应设置接地标志;接地铜排应保证良好接地,接地线截面积应不小于16mm2;

8、机箱内应配备不少于2 路单相2 孔扁圆电源插座、2 路单相3 孔扁圆电源插座

9、电源开关:应具有稳压、短路、过载、漏电保护;电源保护响应时间应为纳秒级;开关的额定电压、额定电流值应满足设备正常运行的要求;机械寿命应不少于20000 次;具有良好的散热性能。

10、室外大机箱需满足上述使用外,还应可安装前端管理主机

## 交通管道要求

过街管道主要垂直于道路中线埋设,可开挖路段采用DN90 镀锌钢管,不宜开挖路段根据现场情况采用拖拉管(DN90 PE 管)。路口必须在各方向埋设双管。非过街管道采用PE 双壁波纹管。

干线(纵向)路段两接线井之间最大距50m

管道其他技术参数应满足现行的《YDT841 地下通信管道用塑料管》要求,机动车道和非机动车道下管道埋设深度(管顶至路面)应≥0.7m,人行道及绿化带下管道埋设深度(管顶至路面)应≥0.5m。如不能达到上述埋设深度要求应采取混凝土包封或采用钢管等保护措施。管道敷设的坡度应为0.3%-0.4%,不得小于0.25%。其他敷设要求应参照《市政公用工程细部构造做法(湖北省)》中《交通管道预埋断面图》做法。

交通管道开挖后应按原有道路或绿化进行恢复,管线尽量敷设于人行道上,不影响后续的绿化园林施工。

具体详见工程量清单(附表

## 第四章资格审查方法及标准

根据《政府采购法》、《政府采购法实施条例》、《政府采购货物和服务招标投标管理
    """
    user_query2="一年有几个月？"
    num_threads = 100  # 并发线程数量
    # 执行多线程调用
    responses = multi_threaded_calls_doubao(user_query, num_threads)
    # 打印所有响应
    # for idx, response in enumerate(responses, start=1):
    #     print(f"响应 {idx}: {response}")
